@@ -67,7 +67,7 @@ Q_SIGNALS:
     void datesSelected(const KCalendarCore::DateList &, const QDate &preferredMonth);
     void incidenceDropped(const Akonadi::Item &, const QDate &);
     void incidenceDroppedMove(const Akonadi::Item &, const QDate &);
-    void newEventSignal(const QDate &, const QDate &);
+    void newEventSignal(const QDate &);
     void newTodoSignal(const QDate &);
     void newJournalSignal(const QDate &);
 
