@@ -36,28 +36,12 @@ void KOWindowList::removeWindow(KOrg::MainWindow *korg)
     }
 }
 
-bool KOWindowList::lastInstance()
-{
-    const int countWindow = mWindowList.count();
-    if (countWindow == 1 && !mDefaultWindow) {
-        return true;
-    }
-
-    if (countWindow == 0 && mDefaultWindow) {
-        return true;
-    } else {
-        return false;
-    }
-}
-
 KOrg::MainWindow *KOWindowList::findInstance(const QUrl &url)
 {
-    for (KOrg::MainWindow *inst : std::as_const(mWindowList)) {
-        if (inst && inst->getCurrentURL() == url) {
-            return inst;
-        }
-    }
-    return nullptr;
+    const auto it = std::ranges::find_if(mWindowList, [url](const KOrg::MainWindow *inst) {
+        return (inst && inst->getCurrentURL() == url);
+    });
+    return (it == mWindowList.end()) ? nullptr : (*it);
 }
 
 KOrg::MainWindow *KOWindowList::defaultInstance()
