@@ -36,11 +36,6 @@ public:
     KOWindowList();
     ~KOWindowList() override;
 
-    /**
-      Is there only one instance left?
-    */
-    [[nodiscard]] bool lastInstance();
-
     /**
       Is there a instance with this URL?
     */
