@@ -35,6 +35,9 @@ public:
     KOEventPopupMenu *mPopup = nullptr;
 
 private:
+    // disable copy ctor
+    KOAgendaViewPrivate(const KOAgendaViewPrivate &) = delete;
+    KOAgendaViewPrivate &operator=(const KOAgendaViewPrivate &) = delete;
     KOAgendaView *const q;
 };
 
@@ -195,11 +198,6 @@ void KOAgendaView::showIncidences(const Akonadi::Item::List &incidences, const Q
     d->mAgendaView->showIncidences(incidences, date);
 }
 
-void KOAgendaView::changeIncidenceDisplayAdded(const Akonadi::Item &)
-{
-    // Do nothing, EventViews::AgendaView knows when items change
-}
-
 void KOAgendaView::changeIncidenceDisplay(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType)
 {
     // Do nothing, EventViews::AgendaView knows when items change
