@@ -30,19 +30,19 @@ public:
     explicit KOJournalView(QWidget *parent = nullptr);
     ~KOJournalView() override;
 
-    Q_REQUIRED_RESULT int currentDateCount() const override;
-    Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() override;
+    [[nodiscard]] int currentDateCount() const override;
+    [[nodiscard]] Akonadi::Item::List selectedIncidences() override;
 
-    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() override
+    [[nodiscard]] KCalendarCore::DateList selectedIncidenceDates() override
     {
         return {};
     }
 
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &) override;
+    void setModel(QAbstractItemModel *model) override;
 
     void getHighlightMode(bool &highlightEvents, bool &highlightTodos, bool &highlightJournals) override;
 
-    Q_REQUIRED_RESULT CalendarSupport::CalPrinterBase::PrintType printType() const override;
+    [[nodiscard]] CalendarSupport::CalPrinterBase::PrintType printType() const override;
 
 public Q_SLOTS:
     void updateView() override;
@@ -55,6 +55,9 @@ public Q_SLOTS:
     void setIncidenceChanger(Akonadi::IncidenceChanger *changer) override;
     void printJournal(const KCalendarCore::Journal::Ptr &journal, bool preview);
 
+    void calendarAdded(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+    void calendarRemoved(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+
 private:
     EventViews::JournalView *const mJournalView;
 };
