@@ -30,13 +30,13 @@ class KOListView : public KOEventView
 {
     Q_OBJECT
 public:
-    explicit KOListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent = nullptr, bool nonInteractive = false);
+    explicit KOListView(QWidget *parent = nullptr, bool nonInteractive = false);
     ~KOListView() override;
 
-    Q_REQUIRED_RESULT int maxDatesHint() const override;
-    Q_REQUIRED_RESULT int currentDateCount() const override;
-    Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() override;
-    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() override;
+    [[nodiscard]] int maxDatesHint() const override;
+    [[nodiscard]] int currentDateCount() const override;
+    [[nodiscard]] Akonadi::Item::List selectedIncidences() override;
+    [[nodiscard]] KCalendarCore::DateList selectedIncidenceDates() override;
 
     // Shows all incidences of the calendar
     void showAll();
@@ -47,10 +47,9 @@ public:
     void clear();
     QSize sizeHint() const override;
 
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &cal) override;
     void setIncidenceChanger(Akonadi::IncidenceChanger *changer) override;
 
-    Q_REQUIRED_RESULT CalendarSupport::CalPrinterBase::PrintType printType() const override;
+    [[nodiscard]] CalendarSupport::CalPrinterBase::PrintType printType() const override;
 
 public Q_SLOTS:
     void updateView() override;
@@ -66,6 +65,9 @@ public Q_SLOTS:
 
     void popupMenu(const QPoint &);
 
+    void calendarAdded(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+    void calendarRemoved(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+
 private:
     KOEventPopupMenu *mPopupMenu = nullptr;
     EventViews::ListView *mListView = nullptr;
